@@ -1,2 +1,2 @@
-from ._AssistantGui import AssistantGUI
+from ._Assistant import Assistant
 from ._napari_plugin import napari_plugin
\ No newline at end of file
